==> swiffy_slider-1.2.x-dev.tar.gz: swiffy_slider/src/Plugin/views/style/SwiffySlider.php <==
<?php

declare(strict_types=1);

namespace Drupal\swiffy_slider\Plugin\views\style;

use Drupal\Core\Form\FormStateInterface;
use Drupal\swiffy_slider\ConfigurationInterface;
use Drupal\views\Plugin\views\style\StylePluginBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Swiffy Slider style plugin.
 *
 * @ViewsStyle(
 *   id = "swiffy_slider",
 *   title = @Translation("Swiffy Slider"),
 *   help = @Translation("Display rows as swiffy slider."),
 *   theme = "views_style_swiffy_slider",
 *   display_types = {"normal"}
 * )
 */
final class SwiffySlider extends StylePluginBase {

  /**
   * {@inheritdoc}
   */
  protected $usesRowPlugin = TRUE;

  /**
   * {@inheritdoc}
   */
  protected $usesGrouping = FALSE;

  /**
   * Storage for available option given by the library.
   *
   * @var \Drupal\swiffy_slider\ConfigurationInterface
   */
  protected ConfigurationInterface $swiffyOptions;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition,);
    $instance->swiffyOptions = $container->get('swiffy_slider.configuration');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  protected function defineOptions(): array {
    $options = [];
    $options['configuration_url'] = ['default' => ''];
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state): void {
    parent::buildOptionsForm($form, $form_state);
    $form['configuration_url'] = $this->swiffyOptions->configurationUrlElement($this->options['configuration_url']);
  }

}

==> swiffy_slider-1.3.x-dev.tar.gz: swiffy_slider/src/Plugin/views/style/SwiffySlider.php <==
<?php

declare(strict_types=1);

namespace Drupal\swiffy_slider\Plugin\views\style;

use Drupal\Core\Form\FormStateInterface;
use Drupal\swiffy_slider\ConfigurationInterface;
use Drupal\views\Plugin\views\style\StylePluginBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Swiffy Slider style plugin.
 *
 * @ViewsStyle(
 *   id = "swiffy_slider",
 *   title = @Translation("Swiffy Slider"),
 *   help = @Translation("Display rows as swiffy slider."),
 *   theme = "views_style_swiffy_slider",
 *   display_types = {"normal"}
 * )
 */
final class SwiffySlider extends StylePluginBase {

  /**
   * {@inheritdoc}
   */
  protected $usesRowPlugin = TRUE;

  /**
   * {@inheritdoc}
   */
  protected $usesGrouping = FALSE;

  /**
   * Storage for available option given by the library.
   *
   * @var \Drupal\swiffy_slider\ConfigurationInterface
   */
  protected ConfigurationInterface $swiffyOptions;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition): static {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition,);
    $instance->swiffyOptions = $container->get('swiffy_slider.configuration');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  protected function defineOptions(): array {
    $options = [];
    $options['configuration_url'] = ['default' => NULL];
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state): void {
    parent::buildOptionsForm($form, $form_state);
    $form['configuration_url'] = $this->swiffyOptions->configurationUrlElement($this->options['configuration_url']);
  }

  /**
   * {@inheritdoc}
   */
  public function validateOptionsForm(&$form, FormStateInterface $form_state): void {
    if ($form_state->getValue(['style_options', 'configuration_url']) === '') {
      $form_state->setValue(['style_options', 'configuration_url'], NULL);
    }
  }

}
